@@ -6,7 +6,7 @@ from django.conf import settings
 
 from utils import redirect_to_facebook_authorization, parse_signed_request, get_facebook_profile, is_ignored_path
 from models import Facebook, FacebookPage, User, OAuthToken
-from settings import IGNORE_PATHS, FACEBOOK_APPLICATION_URL, FACEBOOK_APPLICATION_SECRET_KEY
+from settings import FACEBOOK_APPLICATION_URL, FACEBOOK_APPLICATION_SECRET_KEY
 
 class FacebookMiddleware():
     """Middleware for Facebook applications."""
@@ -21,6 +21,17 @@ class FacebookMiddleware():
         if 'signed_request' in request.REQUEST or 'signed_request' in request.COOKIES:
             request.facebook = Facebook()
             
+            # If the request method is POST and its body only contains the signed request,
+            # chances are it's a request from the Facebook platform and we'll override
+            # the request method to HTTP GET to rectify their misinterpretation
+            # of the HTTP protocol standard.
+            #
+            # References: 
+            # "POST for Canvas" migration at http://developers.facebook.com/docs/canvas/post/
+            # "Incorrect use of the HTTP protocol" discussion at http://forum.developers.facebook.net/viewtopic.php?id=93554
+            if request.method == 'POST' and 'signed_request' in request.POST:
+                request.method = 'GET'
+            
             request.facebook.signed_request = request.REQUEST.get('signed_request') or request.COOKIES.get('signed_request')
             
             facebook_data = parse_signed_request(
